@@ -31,7 +31,12 @@ sub home : Path('/player') {
 	# Get regions 
 	my @regions = $c->model('DBIC::Region')->search({},{order_by => 'id'})->all;
 	$c->stash->{regions} = \@regions;
-	
+    # Picks made per region
+    my $number_of_picks_per_region = $c->model('DBIC')->count_region_picks($player_id);
+    $c->stash->{picks_per_region} = $number_of_picks_per_region;	
+    # Number of Final 4 picks
+    my $number_of_picks_per_final4 = $c->model('DBIC')->count_final4_picks($player_id);
+    $c->stash->{picks_per_final4} = $number_of_picks_per_final4;	
 	return;
 }
 
@@ -57,6 +62,17 @@ sub all : Global {
 	$c->stash->{players} = \@players;
 	my @regions = $c->model('DBIC::Region')->search({},{order_by => 'id'})->all;
 	$c->stash->{regions} = \@regions;
+
+	# Count of picks already made per player
+	# This is useful to see overall pick status. 
+	# TODO: Could be turned off when games start.
+    my $number_of_picks_per_player = $c->model('DBIC')->count_player_picks;
+    $c->stash->{picks_per_player} = $number_of_picks_per_player;
+	# Count of correct picks per player
+	# TODO: Should be turned on when games start.
+    my $number_of_correct_picks_per_player = $c->model('DBIC')->count_player_picks_correct;
+    $c->stash->{correct_picks_per_player} = $number_of_correct_picks_per_player;
+
 }
 
 
